searchData={"items":[{"type":"module","title":"ContentfulElixir","doc":"Provides functions to interact with the Contentful Content Delivery API,\nallowing for fetching entries, assets, and lists of entries based on content type and locale.\n\nThis module is designed to facilitate easy integration with Contentful for Elixir applications,\nabstracting away the HTTP request handling and focusing on returning the relevant content directly to the caller.","ref":"ContentfulElixir.html"},{"type":"module","title":"Configuration - ContentfulElixir","doc":"The module relies on the following module attributes to be set for making API requests:\n\n- `@base_url`: The base URL for the Contentful API. Typically, this would be set to Contentful's Content Delivery API endpoint.\n- `@space_id`: The Space ID provided by Contentful, which identifies the content space from which to fetch data.\n- `@access_token`: The access token for authenticating requests to the Contentful API. This should be a Content Delivery API access token with permissions appropriate for the requested operations.\n\nIt is essential to configure these attributes correctly for the module functions to operate. These can be set directly in the module or dynamically before the module functions are called, depending on the application's configuration strategy.","ref":"ContentfulElixir.html#module-configuration"},{"type":"module","title":"Available Functions - ContentfulElixir","doc":"- `fetch_entry/2`: Fetches a single entry by its ID and optional locale.\n- `fetch_asset/2`: Retrieves a single asset by its ID and optional locale.\n- `fetch_entries/2`: Gets a list of entries filtered by content type and optional locale.\n\nEach function is designed to return an `{:ok, data}` tuple on success, where `data` contains the requested Contentful resource. In case of an error (such as a network error or if the requested resource does not exist), the functions will raise an error, indicating that the operation was unsuccessful.","ref":"ContentfulElixir.html#module-available-functions"},{"type":"module","title":"Usage Example - ContentfulElixir","doc":"config :my_app, ContentfulElixir,\n      base_url: \"https://cdn.contentful.com\",\n      space_id: \"your_space_id\",\n      access_token: \"your_access_token\"\n\n    # Fetch a specific entry\n    {:ok, entry} = ContentfulElixir.fetch_entry(\"entry_id\")\n\n    # Fetch a specific asset\n    {:ok, asset} = ContentfulElixir.fetch_asset(\"asset_id\")\n\n    # Fetch entries of a specific content type\n    {:ok, entries} = ContentfulElixir.fetch_entries(\"content_type\")\n\nEnsure that error handling is implemented in the calling code to gracefully handle potential exceptions raised by these functions.","ref":"ContentfulElixir.html#module-usage-example"},{"type":"function","title":"ContentfulElixir.fetch_asset/2","doc":"Fetches an asset from Contentful using the specified asset ID and locale.\n\nThis function issues a GET request to the Contentful API to retrieve a specific asset identified by its asset ID. It allows for specifying the locale of the asset information, defaulting to \"en-US\" if not provided. The function anticipates a successful response (HTTP status 200) from Contentful and returns the response body containing the asset data wrapped in an `:ok` tuple. If the request is unsuccessful, `Req.get!` will raise an error.","ref":"ContentfulElixir.html#fetch_asset/2"},{"type":"function","title":"Parameters - ContentfulElixir.fetch_asset/2","doc":"- `asset_id`: The unique identifier for the asset to fetch. This parameter is required.\n- `locale`: The locale for the asset data to retrieve. Defaults to \"en-US\" if not specified.","ref":"ContentfulElixir.html#fetch_asset/2-parameters"},{"type":"function","title":"Returns - ContentfulElixir.fetch_asset/2","doc":"- `{:ok, asset}`: Returns an `:ok` tuple with the asset data as received from Contentful in the case of a successful request.","ref":"ContentfulElixir.html#fetch_asset/2-returns"},{"type":"function","title":"Examples - ContentfulElixir.fetch_asset/2","doc":"iex> Kredentials.Content.fetch_asset(\"someAssetId\")\n    {:ok, %{\"fields\" => %{\"title\" => \"Asset Title\", \"file\" => %{\"url\" => \"//assets.ctfassets.net/...\"}}, ...}}\n\n    iex> Kredentials.Content.fetch_asset(\"someAssetId\", \"de-DE\")\n    {:ok, %{\"fields\" => %{\"title\" => \"Asset-Titel\", \"file\" => %{\"url\" => \"//assets.ctfassets.net/...\"}}, ...}}","ref":"ContentfulElixir.html#fetch_asset/2-examples"},{"type":"function","title":"Errors - ContentfulElixir.fetch_asset/2","doc":"- If the Contentful API request fails or does not return a 200 status code, `Req.get!` will raise an error. It is advised to handle potential errors in the calling code, potentially using `try` and `catch`, or by employing `Req.get` instead of `Req.get!` for more nuanced error handling.","ref":"ContentfulElixir.html#fetch_asset/2-errors"},{"type":"function","title":"Notes - ContentfulElixir.fetch_asset/2","doc":"- The function necessitates the configuration of `@base_url`, `@space_id`, and `@access_token` module attributes with appropriate values to access the Contentful API.\n- The API access token must have the required permissions to access assets within the specified space.","ref":"ContentfulElixir.html#fetch_asset/2-notes"},{"type":"function","title":"ContentfulElixir.fetch_entries/2","doc":"Fetches a list of entries of a specific content type from Contentful for a given locale.\n\nThis function sends a GET request to the Contentful API to retrieve entries that match a specified content type. It allows specifying the locale of the entries, defaulting to \"en-US\" if not provided. The function expects a successful response (HTTP status 200) from Contentful and returns the entries wrapped in an `:ok` tuple. If the request fails or does not return a 200 status code, `Req.get!` will raise an error.","ref":"ContentfulElixir.html#fetch_entries/2"},{"type":"function","title":"Parameters - ContentfulElixir.fetch_entries/2","doc":"- `content_type`: The Contentful content type ID for which to fetch entries. This parameter is required.\n- `locale`: The locale for the entries data to retrieve. Defaults to \"en-US\" if not specified.","ref":"ContentfulElixir.html#fetch_entries/2-parameters"},{"type":"function","title":"Returns - ContentfulElixir.fetch_entries/2","doc":"- `{:ok, entries}`: On success, returns an `:ok` tuple with a list of entries as received from Contentful in response to the request.","ref":"ContentfulElixir.html#fetch_entries/2-returns"},{"type":"function","title":"Examples - ContentfulElixir.fetch_entries/2","doc":"iex> Kredentials.Content.fetch_entries(\"blogPost\")\n    {:ok, [%{\"title\" => \"First Post\", \"body\" => \"Hello, world!\"}, ...]}\n\n    iex> Kredentials.Content.fetch_entries(\"blogPost\", \"de-DE\")\n    {:ok, [%{\"title\" => \"Erster Beitrag\", \"body\" => \"Hallo Welt!\"}, ...]}","ref":"ContentfulElixir.html#fetch_entries/2-examples"},{"type":"function","title":"Errors - ContentfulElixir.fetch_entries/2","doc":"- If the Contentful API request fails or does not return a 200 status code, `Req.get!` will raise an error. It is recommended to handle potential errors in the calling code, potentially using `try` and `catch`, or by using `Req.get` instead of `Req.get!` for more nuanced error handling.","ref":"ContentfulElixir.html#fetch_entries/2-errors"},{"type":"function","title":"Notes - ContentfulElixir.fetch_entries/2","doc":"- The function requires the configuration of `@base_url`, `@space_id`, and `@access_token` module attributes with appropriate values to access the Contentful API.\n- The API access token must have the required permissions to access entries within the specified space and content type.","ref":"ContentfulElixir.html#fetch_entries/2-notes"},{"type":"function","title":"ContentfulElixir.fetch_entry/2","doc":"Fetches an entry from Contentful based on the provided entry ID and locale.\n\nThis function sends a GET request to the Contentful API, attempting to retrieve a specific content entry by its ID. The entry is fetched for the specified locale, defaulting to \"en-US\" if no locale is provided. The function expects a successful response from Contentful (HTTP status 200) and returns the body of the response wrapped in an `:ok` tuple. If the request does not succeed, `Req.get!` will raise an error.","ref":"ContentfulElixir.html#fetch_entry/2"},{"type":"function","title":"Parameters - ContentfulElixir.fetch_entry/2","doc":"- `entry_id`: The ID of the entry to fetch. This is a required parameter.\n- `locale`: The locale of the entry content to fetch. It defaults to \"en-US\".","ref":"ContentfulElixir.html#fetch_entry/2-parameters"},{"type":"function","title":"Returns - ContentfulElixir.fetch_entry/2","doc":"- `{:ok, entry}`: On success, returns an `:ok` tuple containing the body of the response from Contentful, which includes the requested entry data.","ref":"ContentfulElixir.html#fetch_entry/2-returns"},{"type":"function","title":"Examples - ContentfulElixir.fetch_entry/2","doc":"iex> Kredentials.Content.fetch_entry(\"someEntryId\")\n    {:ok, %{\"fields\" => %{\"title\" => \"Entry Title\", \"description\" => \"Entry Description\"}, ...}}\n\n    iex> Kredentials.Content.fetch_entry(\"someEntryId\", \"de-DE\")\n    {:ok, %{\"fields\" => %{\"title\" => \"Eintragstitel\", \"description\" => \"Eintragsbeschreibung\"}, ...}}","ref":"ContentfulElixir.html#fetch_entry/2-examples"},{"type":"function","title":"Errors - ContentfulElixir.fetch_entry/2","doc":"- If the request to Contentful fails or does not return a 200 status code, `Req.get!` will raise an error. It's recommended to handle potential errors in the calling code, possibly using `try` and `catch` or by leveraging `Req.get` instead of `Req.get!` for more granular error handling.","ref":"ContentfulElixir.html#fetch_entry/2-errors"},{"type":"function","title":"Notes - ContentfulElixir.fetch_entry/2","doc":"- This function requires the configuration of `@base_url`, `@space_id`, and `@access_token` module attributes, which should be set to appropriate values for accessing the Contentful API.\n- Ensure that the API access token has sufficient permissions to read entries in the specified space.","ref":"ContentfulElixir.html#fetch_entry/2-notes"},{"type":"module","title":"ContentfulElixir.LiveHelpers","doc":"Provides helper functions to render HTML content from Contentful data structures.\n\nThis module is designed to transform Contentful's rich text and other complex data types into HTML for display on web pages. It supports a variety of Contentful node types, such as paragraphs, headings, lists, and hyperlinks, converting them into their corresponding HTML tags. This allows for a direct and flexible way to integrate Contentful content into Phoenix LiveView applications or any Elixir-based web rendering context.\n\nThe main function, `render_content/2`, accepts Contentful data as input and returns a string of HTML. It is capable of handling both individual content entries and lists of entries, making it versatile for different types of content structures fetched from Contentful.","ref":"ContentfulElixir.LiveHelpers.html"},{"type":"module","title":"Usage - ContentfulElixir.LiveHelpers","doc":"The `render_content/2` function can be used within Phoenix templates or LiveViews to dynamically render HTML content based on the data retrieved from Contentful. This simplifies the process of incorporating Contentful's managed content into Elixir applications, providing an easy-to-use interface for content transformation.","ref":"ContentfulElixir.LiveHelpers.html#module-usage"},{"type":"module","title":"Examples - ContentfulElixir.LiveHelpers","doc":"# Rendering a list of content blocks from Contentful\n    contentful_data = [\n      %{\"nodeType\" => \"paragraph\", \"content\" => [%{\"nodeType\" => \"text\", \"value\" => \"Hello, world!\"}]},\n      %{\"nodeType\" => \"heading-1\", \"content\" => [%{\"nodeType\" => \"text\", \"value\" => \"Welcome\"}]}\n    ]\n    html_content = ContentfulElixir.LiveHelpers.render_content(contentful_data)\n    # html_content is now \" Hello, world!  Welcome \"\n\nThis module simplifies the integration of Contentful content into your web application, allowing you to focus on the application logic and user experience while easily managing content through Contentful.","ref":"ContentfulElixir.LiveHelpers.html#module-examples"},{"type":"function","title":"ContentfulElixir.LiveHelpers.render_content/2","doc":"Compile elements from contentful direct into html elements","ref":"ContentfulElixir.LiveHelpers.html#render_content/2"},{"type":"extras","title":"ContentfulElixir","doc":"# ContentfulElixir\n\nA simple solution to fetching Contentful entries and assets in Phoenix, with a focus on LiveView.\n\nI built this as existing solutions did not provide an easy way to fetch data based on locales. I also wanted an automated way for content to be rendered, hence the `render_node` method.\n\nI did not need much, but wanted to put this up for anyone else that might have need for it.\n\nIf you have any requests for additional features, open an issue and ideally give me a contentful example so I can understand your use case and how best to implement it.\n\nPRs are also welcome.","ref":"readme.html"},{"type":"extras","title":"Installation - ContentfulElixir","doc":"The package can be installed by adding `contentful_elixir` to your list of dependencies in `mix.exs`:\n\nHexDocs should have all the information you need to get going.\n\n```elixir\ndef deps do\n  [\n    {:contentful_elixir, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown"}